@@ -2,10 +2,6 @@
 go<-function()
 {
 options(warn=-1)
-if (noquote(unlist(format(.Platform)))[1] == "unix") {
-        windows <<- function(record) {
-        }
-     }  
 
 cat("\n")
   file.menu <- c("Start a new project",
@@ -20,7 +16,10 @@ cat("\n")
     else {
     if (pick == 2){
         cat("\n")
-        demostability()
+        ### demostability()
+        stab_test()
+        dev.off()
+        go()
        }
 
     else {
